@@ -89,6 +89,10 @@ class Series(object):
                             # default strip value for applydiff
                             strip=1)
                     hunks = []
+                    if gp.op == 'DELETE':
+                        # deletion hunk will be added to a non-stored list,
+                        # and discarded when the next file event comes around
+                        continue
                     content.append(
                         (gp.path, os.path.join(self.directory, gp.path), hunks))
                 elif event == 'hunk':
